>From a9301f5cfb4e82f716b28615dcf04d9aaaae10fa Mon Sep 17 00:00:00 2001
From: Tadas Slotkus <devtadas@gmail.com>
Date: Sat, 13 Aug 2011 02:28:11 +0300
Subject: [carFl mem 02/21] Copy read_buf_from_file [trivial]

This is named as read_chunk_from_file will be implemented in the next
patch. Copying as dummy programmer uses that for loading it's flash
contents.

Signed-off-by: Tadas Slotkus <devtadas@gmail.com>
---
 flashrom.c |   34 ++++++++++++++++++++++++++++++++++
 1 files changed, 34 insertions(+), 0 deletions(-)

diff --git a/flashrom.c b/flashrom.c
index 2ac8d26..01276ce 100644
--- a/flashrom.c
+++ b/flashrom.c
@@ -1263,6 +1263,40 @@ int read_buf_from_file(unsigned char *buf, unsigned long size,
 	return 0;
 }
 
+int read_chunk_from_file(unsigned char *buf, unsigned long size,
+		       const char *filename)
+{
+	unsigned long numbytes;
+	FILE *image;
+	struct stat image_stat;
+
+	if ((image = fopen(filename, "rb")) == NULL) {
+		perror(filename);
+		return 1;
+	}
+	if (fstat(fileno(image), &image_stat) != 0) {
+		perror(filename);
+		fclose(image);
+		return 1;
+	}
+	if (image_stat.st_size != size) {
+		msg_gerr("Error: Image size doesn't match\n");
+		fclose(image);
+		return 1;
+	}
+	numbytes = fread(buf, 1, size, image);
+	if (fclose(image)) {
+		perror(filename);
+		return 1;
+	}
+	if (numbytes != size) {
+		msg_gerr("Error: Failed to read complete file. Got %ld bytes, "
+			 "wanted %ld!\n", numbytes, size);
+		return 1;
+	}
+	return 0;
+}
+
 int write_buf_to_file(unsigned char *buf, unsigned long size,
 		      const char *filename)
 {
-- 
1.7.6

